import { JsonRpcProvider } from '@ethersproject/providers';
import { Currency, CurrencyAmount, Token, Trade } from './entities';
import { ChainId, TradeType } from './constants';
import { Pair } from './entities/pair';
export declare function getTokens(chainId: ChainId): Promise<{
    [address: string]: Token;
}>;
declare enum PairState {
    NOT_EXISTS = 0,
    EXISTS = 1,
    INVALID = 2
}
export declare function getPairs(currencies: [Currency, Currency][]): Promise<[PairState, Pair | null][]>;
export declare function getTradeExactIn(currencyAmountIn: CurrencyAmount<Currency>, currencyOut: Currency): Promise<Trade<Currency, Currency, TradeType> | null>;
export declare function getTradeExactOut(currencyIn: Currency, currencyAmountOut: CurrencyAmount<Currency>): Promise<Trade<Currency, Currency, TradeType> | null>;
/**
 * Fetch the best price for the given input and output tokens.
 * @param inputTokenAddress address of the input token
 * @param outputTokenAddress address of the output token
 * @param tokenAmount the amount of token amount including its unit. E.g., 1 (ASTR)
 * @param chainId the chain id, default is Astar mainnet
 * @param isExactInput token amount in input token or not, default is true
 */
export declare function getPrice(inputTokenAddress: string, outputTokenAddress: string, tokenAmount: string, chainId?: ChainId, isExactInput?: boolean): Promise<string>;
/**
 * Contains methods for constructing instances of pairs and tokens from on-chain data.
 */
export declare abstract class Fetcher {
    /**
     * Cannot be constructed.
     */
    private constructor();
    /**
     * Fetch information for a given token on the given chain, using the given viem provider.
     * @param chainId chain of the token
     * @param address address of the token on the chain
     * @param provider provider used to fetch the token
     * @param symbol symbol of the token
     * @param name optional name of the token
     */
    static fetchTokenData(chainId: ChainId, address: string, provider: JsonRpcProvider | undefined, symbol: string, name?: string): Promise<Token>;
    /**
     * Fetches information about a pair and constructs a pair from the given two tokens.
     * @param tokenA first token
     * @param tokenB second token
     * @param provider the provider to use to fetch the data
     */
    static fetchPairData(tokenA: Token, tokenB: Token, provider?: JsonRpcProvider): Promise<Pair>;
}
export {};
